@@ -1,7 +1,9 @@
-# $Id: AnalysisI.pm 11480 2007-06-14 14:16:21Z sendu $
+# $Id: AnalysisI.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::AnalysisI
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Martin Senger <martin.senger@gmail.com>
 # For copyright and disclaimer see below.
 #
@@ -37,6 +39,17 @@ the Bioperl mailing list.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
@@ -63,7 +76,7 @@ This software is provided "as is" without warranty of any kind.
 
 =head1 SEE ALSO
 
-L<http://www.ebi.ac.uk/soaplab/Perl_Client.html>.
+http://www.ebi.ac.uk/Tools/webservices/soaplab/guide
 
 =head1 APPENDIX
 
