@@ -2,6 +2,8 @@
 #
 # BioPerl module for Bio::DB::HIV::HIVQueryHelper
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Mark A. Jensen <maj@fortinbras.us>
 #
 # Copyright Mark A. Jensen
@@ -43,6 +45,17 @@ the Bioperl mailing list.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
@@ -57,6 +70,8 @@ Email maj@fortinbras.us
 
 =head1 CONTRIBUTORS
 
+Mark A. Jensen
+
 =head1 APPENDIX
 
 The rest of the documentation details each of the contained packages.
@@ -633,7 +648,13 @@ sub loadHIVSchema {
 		# exists a tag without content, but to convert to hashes 
 		# with content as key, if all tags possess content
 		if (ref($ptr) eq 'HASH') {
-		    $ptr = [keys %{$ptr}];
+		    my @k = keys %{$ptr};
+		    if (grep /desc/, keys %{$ptr->{$k[0]}}) {
+			# slurp the desc's
+			$$h{desc} = [ map { $$ptr{$_}->{desc} } @k ];
+		    }
+		    # now overwrite with keys (descs in same order...)
+		    $ptr = [@k];
 		}
 		elsif (ref($ptr) eq 'ARRAY') {
 		    $ptr = [map { ref eq 'HASH' ? $_->{name} : $_ } @{$ptr}]
@@ -972,7 +993,7 @@ sub _make_q_guts {
 sub _parse_q {
     local $_;
     my $qstr = shift;
-    my $illegal = qr/[^a-zA-Z0-9-_,\.\(\[\{\}\]\)\s'"]/;
+    my $illegal = qr/[^a-zA-Z0-9-_<>=,\.\(\[\{\}\]\)\s'"]/;
     my $pdlm = qr/[\{\[\(\)\]\}]/;
     my %md = ('('=>')', '['=>']','{'=>'}');
     my @tok =  grep !/^\s*$/, split /($pdlm)/, $qstr;
@@ -2072,7 +2093,7 @@ sub put_value {
     my @args = @_;
     my ($keys, $value) = $self->_rearrange([qw( KEYS VALUE )], @args);
     my (@keys, $lastkey);
-    $value ||= new Bio::Annotation::Collection;
+#    $value ||= new Bio::Annotation::Collection;
     @keys = (ref($keys) eq 'ARRAY') ? @$keys : ($keys);
     $lastkey = pop @keys;
     foreach (@keys) {
