@@ -1,9 +1,11 @@
 #!/usr/bin/perl -w
 
-# $Id: Build.pm 15416 2009-01-21 16:46:12Z cjfields $
+# $Id: Build.pm 16123 2009-09-17 12:57:27Z cjfields $
 #
 # BioPerl module for Bio::Root::Build
 #
+# Please direct questions and support issues to <bioperl-l@bioperl.org> 
+#
 # Cared for by Sendu Bala <bix@sendu.me.uk>
 #
 # Copyright Sendu Bala
@@ -14,7 +16,7 @@
 
 =head1 NAME
 
-Bio::Root::Build - A common Module::Build subclass base for Bioperl distributions
+Bio::Root::Build - A common Module::Build subclass base for BioPerl distributions
 
 =head1 SYNOPSIS
 
@@ -41,6 +43,17 @@ the Bioperl mailing list.  Your participation is much appreciated.
   bioperl-l@bioperl.org                  - General discussion
   http://bioperl.org/wiki/Mailing_lists  - About the mailing lists
 
+=head2 Support 
+
+Please direct usage questions or support issues to the mailing list:
+
+I<bioperl-l@bioperl.org>
+
+rather than to the module maintainer directly. Many experienced and 
+reponsive experts will be able look at the problem and quickly 
+address it. Please include a thorough description of the problem 
+with code and data examples if at all possible.
+
 =head2 Reporting Bugs
 
 Report bugs to the Bioperl bug tracking system to help us keep track
@@ -64,35 +77,7 @@ package Bio::Root::Build;
 
 BEGIN {
     # we really need Module::Build to be installed
-    unless (eval "use Module::Build 0.2805; 1") {
-        print "This package requires Module::Build v0.2805 or greater to install itself.\n";
-        
-        require ExtUtils::MakeMaker;
-        my $yn = ExtUtils::MakeMaker::prompt('  Install Module::Build now from CPAN?', 'y');
-        
-        unless ($yn =~ /^y/i) {
-            die " *** Cannot install without Module::Build.  Exiting ...\n";
-        }
-        
-        require Cwd;
-        require File::Spec;
-        require File::Copy;
-        require CPAN;
-        
-        # Save this because CPAN will chdir all over the place.
-        my $cwd = Cwd::cwd();
-        
-        my $build_pl = File::Spec->catfile($cwd, "Build.PL");
-        
-        File::Copy::move($build_pl, $build_pl."hidden"); # avoid bizarre bug with Module::Build tests using the wrong Build.PL if it happens to be in PERL5LIB
-        CPAN::Shell->install('Module::Build');
-        File::Copy::move($build_pl."hidden", $build_pl);
-        CPAN::Shell->expand("Module", "Module::Build")->uptodate or die "Couldn't install Module::Build, giving up.\n";
-        
-        chdir $cwd or die "Cannot chdir() back to $cwd: $!\n\n***\nInstallation will probably work fine if you now quit CPAN and try again.\n***\n\n";
-    }
-    
-    eval "use base Module::Build; 1" or die $@;
+    eval "use base Module::Build; 1" or die "This package requires Module::Build v0.2805 or greater to install itself.\n$@";
     
     # ensure we'll be able to reload this module later by adding its path to inc
     use Cwd;
@@ -102,7 +87,7 @@ BEGIN {
 use strict;
 use warnings;
 
-our $VERSION = '1.005009_004';
+our $VERSION = '1.006000_001';
 our @extra_types = qw(options excludes_os feature_requires test); # test must always be last in the list!
 our $checking_types = "requires|conflicts|".join("|", @extra_types);
 
@@ -141,7 +126,7 @@ sub choose_scripts {
         }
     }
     closedir($scripts_dir);
-    my $question = $int_ok ? "Install [a]ll Bioperl scripts, [n]one, or choose groups [i]nteractively?" : "Install [a]ll Bioperl scripts or [n]one?";
+    my $question = $int_ok ? "Install [a]ll BioPerl scripts, [n]one, or choose groups [i]nteractively?" : "Install [a]ll BioPerl scripts or [n]one?";
     
     my $prompt = $accept ? 'a' : $self->prompt($question, 'a');
     
@@ -427,7 +412,7 @@ sub prereq_failures {
 # install an external module using CPAN prior to testing and installation
 # should only be called by install_required or install_optional
 sub install_prereq {
-    my ($self, $desired, $version) = @_;
+    my ($self, $desired, $version, $required) = @_;
     
     if ($self->under_cpan) {
         # Just add to the required hash, which CPAN >= 1.81 will check prior
@@ -437,29 +422,39 @@ sub install_prereq {
         return 'ok';
     }
     else {
-        # Here we use CPAN to actually install the desired module, the benefit
-        # being we continue even if installation fails, and that this works
-        # even when not using CPAN to install.
-        require Cwd;
-        require CPAN;
+        my $question = $required ?  "$desired is absolutely required prior to installation: shall I install it now using a CPAN shell?" :
+                                    "To install $desired I'll need to open a CPAN shell right now; is that OK?";
+        my $do_install = $self->y_n($question.' y/n', 'y');
         
-        # Save this because CPAN will chdir all over the place.
-        my $cwd = Cwd::cwd();
-        
-        CPAN::Shell->install($desired);
-        my $msg;
-        my $expanded = CPAN::Shell->expand("Module", $desired);
-        if ($expanded && $expanded->uptodate) {
-            $self->log_info("\n\n*** (back in Bioperl Build.PL) ***\n * You chose to install $desired and it installed fine\n");
-            $msg = 'ok';
+        if ($do_install) {
+            # Here we use CPAN to actually install the desired module, the benefit
+            # being we continue even if installation fails, and that this works
+            # even when not using CPAN to install.
+            require Cwd;
+            require CPAN;
+            
+            # Save this because CPAN will chdir all over the place.
+            my $cwd = Cwd::cwd();
+            
+            CPAN::Shell->install($desired);
+            my $msg;
+            my $expanded = CPAN::Shell->expand("Module", $desired);
+            if ($expanded && $expanded->uptodate) {
+                $self->log_info("\n\n*** (back in BioPerl Build.PL) ***\n * You chose to install $desired and it installed fine\n");
+                $msg = 'ok';
+            }
+            else {
+                $self->log_info("\n\n*** (back in BioPerl Build.PL) ***\n");
+                $msg = "You chose to install $desired but it failed to install";
+            }
+            
+            chdir $cwd or die "Cannot chdir() back to $cwd: $!";
+            return $msg;
         }
         else {
-            $self->log_info("\n\n*** (back in Bioperl Build.PL) ***\n");
-            $msg = "You chose to install $desired but it failed to install";
+            return $required ? "You chose not to install the REQUIRED module $desired: you'd better install it yourself manually!" :
+                               "Even though you wanted the optional module $desired, you chose not to actually install it: do it yourself manually.";
         }
-        
-        chdir $cwd or die "Cannot chdir() back to $cwd: $!";
-        return $msg;
     }
 }
 
@@ -470,7 +465,7 @@ sub install_required {
     
     $self->log_info(" - ERROR: $msg\n");
     
-    return $self->install_prereq($desired, $version);
+    return $self->install_prereq($desired, $version, 1);
 }
 
 # install optional modules listed in 'recommends' arg to new that weren't
@@ -513,32 +508,51 @@ sub under_cpan {
     unless (defined $self->{under_cpan}) {
         ## modified from Module::AutoInstall
         
-        # load cpan config
-        require CPAN;
-        if ($CPAN::HandleConfig::VERSION) {
-            # Newer versions of CPAN have a HandleConfig module
-            CPAN::HandleConfig->load;
-        }
-        else {
-            # Older versions had the load method in Config directly
-            CPAN::Config->load;
+        my $cpan_env = $ENV{PERl5_CPAN_IS_RUNNING};
+        if ($ENV{PERL5_CPANPLUS_IS_RUNNING}) {
+            $self->{under_cpan} = $cpan_env ? 'CPAN' : 'CPANPLUS';
         }
         
-        # Find the CPAN lock-file
-        my $lock = File::Spec->catfile($CPAN::Config->{cpan_home}, '.lock');
-        if (-f $lock) {
-            # Module::AutoInstall now goes on to open the lock file and compare
-            # its pid to ours, but we're not in a situation where we expect
-            # the pids to match, so we take the windows approach for all OSes:
-            # find out if we're in cpan_home
-            my $cwd  = File::Spec->canonpath(Cwd::cwd());
-            my $cpan = File::Spec->canonpath($CPAN::Config->{cpan_home});
+        require CPAN;
+        
+        unless (defined $self->{under_cpan}) {
+            if ($CPAN::VERSION > '1.89') {
+                if ($cpan_env) {
+                    $self->{under_cpan} = 'CPAN';
+                }
+                else {
+                    $self->{under_cpan} = 0;
+                }
+            }
+        }
+        
+        unless (defined $self->{under_cpan}) {
+            # load cpan config
+            if ($CPAN::HandleConfig::VERSION) {
+                # Newer versions of CPAN have a HandleConfig module
+                CPAN::HandleConfig->load;
+            }
+            else {
+                # Older versions had the load method in Config directly
+                CPAN::Config->load;
+            }
             
-            $self->{under_cpan} = index($cwd, $cpan) > -1;
+            # Find the CPAN lock-file
+            my $lock = File::Spec->catfile($CPAN::Config->{cpan_home}, '.lock');
+            if (-f $lock) {
+                # Module::AutoInstall now goes on to open the lock file and compare
+                # its pid to ours, but we're not in a situation where we expect
+                # the pids to match, so we take the windows approach for all OSes:
+                # find out if we're in cpan_home
+                my $cwd  = File::Spec->canonpath(Cwd::cwd());
+                my $cpan = File::Spec->canonpath($CPAN::Config->{cpan_home});
+                
+                $self->{under_cpan} = index($cwd, $cpan) > -1;
+            }
         }
         
         if ($self->{under_cpan}) {
-            $self->log_info("(I think I'm being run by CPAN, so will rely on CPAN to handle prerequisite installation)\n");
+            $self->log_info("(I think I'm being run by CPAN/CPANPLUS, so will rely on it to handle prerequisite installation)\n");
         }
         else {
             $self->log_info("(I think you ran Build.PL directly, so will use CPAN to install prerequisites on demand)\n");
@@ -708,9 +722,11 @@ sub _parse_conditions {
 }
 
 # when generating META.yml, we output optional_features syntax (instead of
-# recommends syntax). Note that as of CPAN v1.8802 nothing useful is done
+# recommends syntax). Note that as of CPAN v1.9402 nothing useful is done
 # with this information, which is why we implement our own request to install
-# the optional modules in install_optional()
+# the optional modules in install_optional().
+# Also note that CPAN PLUS complains with an [ERROR] when it sees this META.yml,
+# but it isn't fatal and installation continues fine.
 sub prepare_metadata {
     my ($self, $node, $keys) = @_;
     my $p = $self->{properties};
